<?php
/**
 * Register customizations
 *
 * @since 1.0.0
 * @package coldbox
 */

/**
 * Enqueue customizer CSS
 *
 * @since 1.0.0
 */
function cd_czr_style() {
	wp_enqueue_style( 'cd-czr-style', get_template_directory_uri() . '/czr/czr-style.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'cd_czr_style' );

/*
 * -------------------------------------------------------------------------
 *  Theme Customizer
 * -------------------------------------------------------------------------
 */
if ( ! function_exists( 'cd_customize_register' ) ) {
	/**
	 * Register customzer settings.
	 *
	 * @since 1.0.0
	 * @param string $wp_customize the customizations registered.
	 */
	function cd_customize_register( $wp_customize ) {

		/**
		 * Define the sanitization function for checkboxes.
		 *
		 * @since 1.0.0
		 * @param bool $checked The strings that will be checked.
		 */
		function cd_sanitize_checkbox( $checked ) {
			return ( ( isset( $checked ) && true === $checked ) ? true : false );
		}
		/**
		 * Define the sanitization function for radio bottom / select boxes.
		 *
		 * @since 1.0.0
		 * @param string $input The strings that will be checked.
		 * @param string $setting The possible choices.
		 */
		function cd_sanitize_radio( $input, $setting ) {
			$input = sanitize_key( $input );
			$choices = $setting -> manager -> get_control( $setting -> id ) -> choices;
			return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
		}
		/**
		 * Define the sanitization function for text.
		 *
		 * @since 1.0.0
		 * @param string $text The strings that will be checked.
		 */
		function cd_sanitize_text( $text ) {
			return sanitize_text_field( $text );
		}

		// To output HTML.
		get_template_part( 'czr/class-cd-custom-content' );

		/*
		 * -------------------------------------------------------------------------
		 *  Global Settings
		 * -------------------------------------------------------------------------
		 */
		$wp_customize->add_section( 'global', array(
			'title'  => __( 'Coldbox: Global Settings', 'coldbox' ),
			'priority' => 1,
		));
		// Sidebar Position.
		$wp_customize->add_setting( 'sidebar_position', array(
			'default'  => 'right',
			'sanitize_callback' => 'cd_sanitize_radio',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'sidebar_position', array(
			'label'    => __( 'Sidebar Position', 'coldbox' ),
			'section'  => 'global',
			'priority' => 1,
			'type'     => 'radio',
			'choices'  => array(
				'right'    => __( 'Right Sidebar (default)','coldbox' ),
				'left'     => __( 'Left Sidebar','coldbox' ),
				'bottom'   => __( 'Bottom Sidebar', 'coldbox' ),
				'hide'     => __( 'Hide Sidebar', 'coldbox' ),
			),
		)));
		// Container Width.
		$wp_customize->add_setting( 'container_width', array(
			'default'  => '1140',
			'sanitize_callback' => 'absint',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'container_width', array(
			'label'    => __( 'Site Max-Width', 'coldbox' ),
			'section'  => 'global',
			'type'     => 'number',
			'input_attrs' => array(
				'step'     => '1',
				'min'      => '800',
				'max'      => '1980',
			),
		)));
		// Global Font Select.
		$wp_customize->add_setting( 'global_font', array(
			'default'  => 'sourcesanspro',
			'sanitize_callback' => 'cd_sanitize_radio',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'global_font', array(
			'label'    => __( 'Global Font Selecter', 'coldbox' ),
			'section'  => 'global',
			'type'     => 'select',
			'choices'  => array(
				'sourcesanspro' => 'Source Sans Pro',
				'opensans'  => 'Open Sans',
				'lato'      => 'Lato',
				'roboto'    => 'Roboto',
				'robotocondensed' => 'Roboto Condensed',
				'ubuntu'    => 'Ubuntu',
				'raleway'   => 'Raleway',
				'josefinsans' => 'Josefin Sans',
				'ptsans'    => 'PT Sans',
				'lora'      => 'Lora',
				'robotoslab' => 'Roboto Slab',
				'arial'     => 'Arial',
				'helvetica' => 'Helvetica',
				'verdana'   => 'Verdana',
				'tahoma'    => 'Tahoma',
			),
		)));
		$wp_customize->add_setting( 'custom_font', array(
			'default'  => '[font], Arial, sans-serif',
			'sanitize_callback' => 'cd_sanitize_text',
		));
		$wp_customize->add_control( new WP_Customize_control( $wp_customize, 'custom_font', array(
			'label'    => __( 'Custom Font-Family Value', 'coldbox' ),
			'description' => sprintf( /* Translators: %s: [font](shortcode) */ __( '"%s" will be replaced with the font you\'ve chosen above', 'coldbox' ), '[font]' ),
			'section'  => 'global',
			'type'     => 'text',
		)));
		$wp_customize->add_setting( 'global_font_size_pc', array(
			'default'  => 17,
			'sanitize_callback' => 'absint',
		));
		$wp_customize->add_control( new WP_Customize_control( $wp_customize, 'global_font_size_pc', array(
			'label'    => __( 'Global Font Size for PC', 'coldbox' ),
			'section'  => 'global',
			'type'     => 'number',
			'input_attrs' => array(
				'step'     => '1',
				'min'      => '10',
				'max'      => '32',
			),
		)));
		$wp_customize->add_setting( 'global_font_size_mobile', array(
			'default'  => 16,
			'sanitize_callback' => 'absint',
		));
		$wp_customize->add_control( new WP_Customize_control( $wp_customize, 'global_font_size_mobile', array(
			'label'    => __( 'Global Font Size for Mobile', 'coldbox' ),
			'section'  => 'global',
			'type'     => 'number',
			'input_attrs' => array(
				'step'     => '1',
				'min'      => '10',
				'max'      => '32',
			),
		)));
		$wp_customize->add_setting( 'minified_css', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_control( $wp_customize, 'minified_css', array(
			'label'    => __( 'Use minified CSS file', 'coldbox' ),
			'description' => __( 'The theme will load minified CSS file. Minifying css stylesheets improves loading speed of your website. It should be used unless you need to modify the theme\'s stylesheet.', 'coldbox' ),
			'section'  => 'global',
			'type'     => 'checkbox',
		)));
		$wp_customize->add_setting( 'minified_js', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_control( $wp_customize, 'minified_js', array(
			'label'    => __( 'Use minified JS file', 'coldbox' ),
			'description' => __( 'The theme will load minified JS file. Minifying JavaScript file improves loading speed of your website. It should be used unless you need to modify the theme\'s stylesheet.', 'coldbox' ),
			'section'  => 'global',
			'type'     => 'checkbox',
		)));
		// Use highlight.js.
		$wp_customize->add_setting( 'does_use_hljs', array(
			'default'  => false,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'does_use_hljs', array(
			'label'  => __( 'Use highlight.js', 'coldbox' ),
			'description' => __( 'The package contains 23 common languages.' , 'coldbox' ),
			'section'  => 'global',
			'type'     => 'checkbox',
		)));
		$wp_customize->add_setting( 'use_hljs_web_pack', array(
			'default'  => false,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'use_hljs_web_pack', array(
			'label'  => __( 'Use highlight.js with Web Package', 'coldbox' ),
			'description' => __( 'The package contains the languages which often be used for web development. To use other languages, you may go to <a href="https://highlightjs.org/">Highlight.js official site</a>.', 'coldbox' ),
			'section'  => 'global',
			'type'     => 'checkbox',
		)));

		/*
		 * -------------------------------------------------------------------------
		 *  Header Settings
		 * -------------------------------------------------------------------------
		 */
		$wp_customize->add_section( 'header', array(
			'title'    => __( 'Coldbox: Header Settings','coldbox' ),
			'priority' => 1,
		));
		// Site Description.
		$wp_customize->add_setting( 'site_title', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'site_title', array(
			'label'    => __( 'Display Site Title', 'coldbox' ),
			'description' => __( 'Even this setting is unchecked, the logo will be still shown.', 'coldbox' ),
			'section'  => 'header',
			'type'     => 'checkbox',
		)));
		// Site Description.
		$wp_customize->add_setting( 'site_desc', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'site_desc', array(
			'label'    => __( 'Display Site Description', 'coldbox' ),
			'section'  => 'header',
			'type'     => 'checkbox',
		)));
		// Header Direction.
		$wp_customize->add_setting( 'header_direction', array(
			'default'  => 'column',
			'sanitize_callback' => 'cd_sanitize_radio',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'header_direction', array(
			'label'    => __( 'Header and Menu Direction', 'coldbox' ),
			'section'  => 'header',
			'type'     => 'radio',
			'choices'  => array(
				'column'  => __( 'Vertical (column)', 'coldbox' ),
				'row'     => __( 'Horizontal (row)', 'coldbox' ),
			),
		)));
		// Sticky Header.
		$wp_customize->add_setting( 'header_sticky', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'header_sticky', array(
			'label'    => __( 'Make Header Sticky', 'coldbox' ),
			'description' => __( 'Only menus will be sticky when vertical is selected, or the whole header will be sticky with narrower padding when horizontal is selected.', 'coldbox' ),
			'section'  => 'header',
			'type'     => 'checkbox',
		)));

		/*
		 * -------------------------------------------------------------------------
		 *  Index settings
		 * -------------------------------------------------------------------------
		 */
		$wp_customize->add_section( 'index', array(
			'title'    => __( 'Coldbox: Archive Pages Settings','coldbox' ),
			'priority' => 2,
		));
		// Front page style.
		$wp_customize->add_setting( 'index_style', array(
			'default'  => 'grid',
			'sanitize_callback' => 'cd_sanitize_radio',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'index_style', array(
			'label'    => __( 'Front Page Style','coldbox' ),
			'section'  => 'index',
			'priority' => 1,
			'type'     => 'radio',
			'choices'  => array(
				'grid'     => __( 'Grid Style (default)','coldbox' ),
				'standard' => __( 'Standard Style','coldbox' ),
			),
		)));
		// Archive page style.
		$wp_customize->add_setting( 'archive_style', array(
			'default'  => 'grid',
			'sanitize_callback' => 'cd_sanitize_radio',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'archive_style', array(
			'label'    => __( 'Archive Page Style','coldbox' ),
			'section'  => 'index',
			'priority' => 2,
			'type'     => 'radio',
			'choices'  => array(
				'grid'     => __( 'Grid Style (default)','coldbox' ),
				'standard' => __( 'Standard Style','coldbox' ),
			),
		)));
		// Excerpt Length Setting.
		$wp_customize->add_setting( 'excerpt_length', array(
			'default'  => '60',
			'sanitize_callback' => 'absint',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'excerpt_length', array(
			'label'    => __( 'Excerpt Length', 'coldbox' ),
			'section'  => 'index',
			'type'     => 'number',
			'input_attrs' => array(
				'min'      => '0',
			),
		)));
		$wp_customize->add_setting( 'excerpt_ending', array(
			'default'  => '...',
			'sanitize_callback' => 'cd_sanitize_text',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'excerpt_ending', array(
			'label'    => __( 'Excerpt Ending', 'coldbox' ),
			'section'  => 'index',
			'type'     => 'text',
		)));
		// Placefoler Setting.
		$wp_customize->add_setting( 'index_placefolder_image', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'index_placefolder_image', array(
			'label'    => __( 'Use Placefolder Images when no Featured Image', 'coldbox' ),
			'section'  => 'index',
			'type'     => 'checkbox',
		)));
		// Meta Settings.
		$wp_customize->add_setting( 'index_meta_date', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'index_meta_date', array(
			'label'    => __( 'Display Post Date on Grid', 'coldbox' ),
			'section'  => 'index',
			'type'     => 'checkbox',
		)));
		$wp_customize->add_setting( 'index_meta_cat', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'index_meta_cat', array(
			'label'    => __( 'Display Categories on Grid', 'coldbox' ),
			'section'  => 'index',
			'type'     => 'checkbox',
		)));
		$wp_customize->add_setting( 'index_meta_comment', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'index_meta_comment', array(
			'label'    => __( 'Display Comments Count on Grid', 'coldbox' ),
			'section'  => 'index',
			'type'     => 'checkbox',
		)));

		/*
		 *------------------------------------------------------------------------- *
		 *  Single Settings
		 * -------------------------------------------------------------------------
		 */
		$wp_customize->add_section( 'single', array(
			'title'    => __( 'Coldbox: Single Settings', 'coldbox' ),
			'priority' => 3,
		));

		/*
		 *  Add decorations to header Tags
		 * --------------------------------------------------
		 */
		$wp_customize->add_setting( 'single_content', array(
			'sanitize_callback' => 'cd_sanitize_text',
		) );
		$wp_customize->add_control( new CD_Custom_Content( $wp_customize, 'single_content', array(
			'content'  => '<h3 class="czr-heading first">' . __( 'Settings for Content', 'coldbox' ) . '</h3>',
			'section'  => 'single',
		) ) );
		$wp_customize->add_setting( 'decorate_htags', array(
			'default'  => false,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'decorate_htags', array(
			'label'    => __( 'Add Decoration to H2-H5 Tags.', 'coldbox' ),
			'section'  => 'single',
			'type'     => 'checkbox',
		)));

		/*
		 * Single Meta Settings
		 * --------------------------------------------------
		*/
		$wp_customize->add_setting( 'single_meta', array(
			'sanitize_callback' => 'cd_sanitize_text',
		) );
		$wp_customize->add_control( new CD_Custom_Content( $wp_customize, 'single_meta', array(
			'content' => '<h3 class="czr-heading">' . __( 'Settings for Metas', 'coldbox' ) . '</h3>',
			'section' => 'single',
		) ) );
		// Date.
		$wp_customize->add_setting( 'single_meta_date', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'single_meta_date', array(
			'label'    => __( 'Display Post Dates', 'coldbox' ),
			'section'  => 'single',
			'type'     => 'checkbox',
		)));
		// Last modified date.
		$wp_customize->add_setting( 'single_meta_modified_date', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'single_meta_modified_date', array(
			'label'    => __( 'Display the last Modified Dates', 'coldbox' ),
			'section'  => 'single',
			'type'     => 'checkbox',
		)));
		// Category.
		$wp_customize->add_setting( 'single_meta_cat', array(
			'default'  => false,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'single_meta_cat', array(
			'label'    => __( 'Display Post Categories','coldbox' ),
			'section'  => 'single',
			'type'     => 'checkbox',
			'description' => __( 'Note: Categories are already shown on the breadcrum.', 'coldbox' ),
		)));
		// Author.
		$wp_customize->add_setting( 'single_meta_author', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'single_meta_author', array(
			'label'    => __( 'Display Post Author','coldbox' ),
			'section'  => 'single',
			'type'     => 'checkbox',
		)));
		// Comment Count.
		$wp_customize->add_setting( 'single_meta_com', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'single_meta_com', array(
			'label'    => __( 'Display Comments Count', 'coldbox' ),
			'section'  => 'single',
			'type'     => 'checkbox',
		)));
		// Bottom Tag.
		$wp_customize->add_setting( 'single_meta_btm_tag', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'single_meta_btm_tag', array(
			'label'    => __( 'Display Post Tags on Bottom', 'coldbox' ),
			'section'  => 'single',
			'type'     => 'checkbox',
		)));
		// Bottom Category.
		$wp_customize->add_setting( 'single_meta_btm_cat', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'single_meta_btm_cat', array(
			'label'    => __( 'Display Post Categories on Bottom', 'coldbox' ),
			'section'  => 'single',
			'type'     => 'checkbox',
		)));
		// Author Box.
		$wp_customize->add_setting( 'single_author_box', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( 'single_author_box', array(
			'label'    => __( 'Display Author Box','coldbox' ),
			'section'  => 'single',
			'type'     => 'checkbox',
		));
		// Comment.
		$wp_customize->add_setting( 'single_comment', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'single_comment', array(
			'label'    => __( 'Display Comments','coldbox' ),
			'section'  => 'single',
			'type'     => 'checkbox',
		)));
		// Post Nav.
		$wp_customize->add_setting( 'single_post_nav', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'single_post_nav', array(
			'label'    => __( 'Display Post Navigation','coldbox' ),
			'section'  => 'single',
			'type'     => 'checkbox',
		)));

		/*
		 * Related Posts Settings
		 * --------------------------------------------------
		 */
		$wp_customize->add_setting( 'single_related', array(
			'sanitize_callback' => 'cd_sanitize_text',
		) );
		$wp_customize->add_control( new CD_Custom_Content( $wp_customize, 'single_related', array(
			'content' => '<h3 class="czr-heading">' . __( 'Settings for Related Posts', 'coldbox' ) . '</h3>',
			'section' => 'single',
		) ) );
		// Related Post.
		$wp_customize->add_setting( 'single_related_posts', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'single_related_posts', array(
			'label'    => __( 'Display Related Posts','coldbox' ),
			'section'  => 'single',
			'type'     => 'checkbox',
		)));
		// Max Article.
		$wp_customize->add_setting( 'single_related_max', array(
			'default'  => 6,
			'sanitize_callback' => 'absint',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'single_related_max', array(
			'label'    => __( 'Related Post - Max Articles', 'coldbox' ),
			'section'  => 'single',
			'type'     => 'number',
			'input_attrs' => array(
				'min'      => '1',
			),
		)));
		// Max Article.
		$wp_customize->add_setting( 'single_related_col', array(
			'default'  => 3,
			'sanitize_callback' => 'absint',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'single_related_col', array(
			'label'    => __( 'Related Post - Columns', 'coldbox' ),
			'section'  => 'single',
			'type'     => 'number',
			'input_attrs' => array(
				'min'      => '1',
			),
		)));

		/*
		 * ------------------------------------------------------------------------- *
		 *  Static Pages Settings
		 * -------------------------------------------------------------------------
		 */
		$wp_customize->add_section( 'pages', array(
			'title'    => __( 'Coldbox: Static Pages Settings', 'coldbox' ),
			'priority' => 3,
		));

		/*
		 * Pages Meta Settings
		 * --------------------------------------------------
		 */

		// Data.
		$wp_customize->add_setting( 'pages_meta_date', array(
			'default'  => false,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'pages_meta_date', array(
			'label'    => __( 'Display Post Dates', 'coldbox' ),
			'section'  => 'pages',
			'type'     => 'checkbox',
		)));
		// Author.
		$wp_customize->add_setting( 'pages_meta_author', array(
			'default'  => false,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'pages_meta_author', array(
			'label'    => __( 'Display Author Names', 'coldbox' ),
			'section'  => 'pages',
			'type'     => 'checkbox',
		)));
		// Comments count.
		$wp_customize->add_setting( 'pages_meta_comments_count', array(
			'default'  => false,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'pages_meta_comments_count', array(
			'label'    => __( 'Display Comments Counts', 'coldbox' ),
			'description' => __( 'It will be shown when comments are opened and shown.', 'coldbox' ),
			'section'  => 'pages',
			'type'     => 'checkbox',
		)));

		/*
		 * ------------------------------------------------------------------------- *
		 *  Footer Settings
		 * -------------------------------------------------------------------------
		 */
		$wp_customize->add_section( 'footer', array(
			'title'    => __( 'Coldbox: Footer Settings', 'coldbox' ),
			'priority' => 4,
		));
		$wp_customize->add_setting( 'theme_credit', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
			'priority' => 5,
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'theme_credit', array(
			'label'    => __( 'Display Theme Credit', 'coldbox' ),
			'section'  => 'footer',
			'type'     => 'checkbox',
		)));
		$wp_customize->add_setting( 'credit_text', array(
			'default'  => '©[year] <a href="[url]">[name]</a>',
			'sanitize_callback' => 'wp_kses_post',
			'priority' => 1,
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'credit_text', array(
			'label'    => __( 'Edit the Credit Content', 'coldbox' ),
			'description' => sprintf( /* Translators: %s: HTML Tags. */ __( 'It will be displayed in footer area. You can use the following HTML tags: %s.<br/> Also some shortcodes you can use: <br/> [year] -> Shows this year, <br/> [url] -> This site\'s URL, <br/> [name] -> This site\'s name.', 'coldbox' ), '&lt;a&gt;, &lt;p&gt;, &lt;br&gt;, &lt;b&gt;, &lt;strong&gt; &lt;small&gt;' ),
			'section'  => 'footer',
			'type'     => 'textarea',
		)));
		$wp_customize->add_setting( 'theme_credit_text', array(
			'default'  => __( 'Coldbox WordPress theme by', 'coldbox' ) . ' <a href="' . esc_url( __( 'https://miruc.co/', 'coldbox' ) ) . '">' . __( 'Mirucon', 'coldbox' ) . '</a>',
			'sanitize_callback' => 'wp_kses_post',
			'priority' => 10,
		));
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'theme_credit_text', array(
			'label'    => __( 'Edit the Theme Credit Content', 'coldbox' ),
			'description' => sprintf( /* Translators: %s: HTML Tags. */ __( 'It will be displayed when above checked. You can use the following HTML tags: %s', 'coldbox' ), '&lt;a&gt;, &lt;p&gt;, &lt;br&gt;, &lt;b&gt;, &lt;strong&gt; &lt;small&gt;' ),
			'section'  => 'footer',
			'type'     => 'textarea',
		)));

		/*
		 * ------------------------------------------------------------------------- *
		 *  Colors
		 * -------------------------------------------------------------------------
		 */

		// Link Color.
		$wp_customize->add_setting( 'link_color', array(
			'default'    => '#00619f',
			'sanitize_callback' => 'sanitize_hex_color',
		));
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_color', array(
			'label'      => __( 'Primary Color', 'coldbox' ),
			'section'    => 'colors',
			'settings'   => 'link_color',
			'priority' => 10,
		)));
		// Hover Link Color.
		$wp_customize->add_setting( 'link_hover_color', array(
			'default'   => '#2e4453',
			'sanitize_callback' => 'sanitize_hex_color',
		));
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_hover_color', array(
			'label'     => __( 'Secondary Color', 'coldbox' ),
			'section'   => 'colors',
			'settings'  => 'link_hover_color',
			'priority' => 20,
		)));
		// Header Background Color.
		$wp_customize->add_setting( 'header_color', array(
			'default'  => '#ffffff',
			'sanitize_callback' => 'sanitize_hex_color',
		));
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_color', array(
			'label'     => __( 'Header Background Color', 'coldbox' ),
			'section'   => 'colors',
			'settings'  => 'header_color',
			'priority' => 30,
		)));
		// Footer Background Color.
		$wp_customize->add_setting( 'footer_color', array(
			'default'  => '#44463b',
			'sanitize_callback' => 'sanitize_hex_color',
		));
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_color', array(
			'label'     => __( 'Footer Background Color', 'coldbox' ),
			'section'   => 'colors',
			'settings'  => 'footer_color',
			'priority' => 100,
		)));
		$wp_customize->get_setting( 'header_textcolor' )->default = '#444444';
		$wp_customize->get_control( 'header_textcolor' )->priority = 50;
		$wp_customize->get_control( 'background_color' )->priority = 22;

		/*
		 * ------------------------------------------------------------------------- *
		 *  Social Links
		 * --------------------------------------------------------------------------
		 */
		$wp_customize->add_setting( 'links_on_author_box', array(
			'default'  => true,
			'sanitize_callback' => 'cd_sanitize_checkbox',
		));

		$wp_customize->add_control( 'links_on_author_box', array(
			'label'   => __( 'Show the social links on the author box', 'coldbox' ),
			'section' => 'social_links',
			'type'    => 'checkbox',
			'priority' => '1',
		));

	} // End Customizer.


	/**
	 * Get whether using minified CSS or not
	 *
	 * @since 1.0.0
	 */
	function cd_use_minified_css() {
		return ( get_theme_mod( 'minified_css', true ) );
	}
	/**
	 * Get whether using minified JS or not
	 *
	 * @since 1.0.0
	 */
	function cd_use_minified_js() {
		return ( get_theme_mod( 'minified_js', true ) );
	}
	/**
	 * Get the sidebar position
	 *
	 * @since 1.0.0
	 */
	function cd_sidebar_stg() {
		return ( get_theme_mod( 'sidebar_position', 'right' ) );
	}
	/**
	 * Get page style for index pages
	 *
	 * @since 1.0.0
	 */
	function cd_index_style() {
		return ( get_theme_mod( 'index_style', 'grid' ) );
	}
	/**
	 * Get page style for archive pages
	 *
	 * @since 1.0.0
	 */
	function cd_archive_style() {
		return ( get_theme_mod( 'archive_style', 'grid' ) );
	}
	/**
	 * Get whether displaying the site title or not
	 *
	 * @since 1.0.2
	 */
	function cd_is_site_title() {
		return ( get_theme_mod( 'site_title', true ) );
	}
	/**
	 * Get whether dispyaing the site tagline or not
	 *
	 * @since 1.0.0
	 */
	function cd_is_site_desc() {
		return ( get_theme_mod( 'site_desc', true ) );
	}
	/**
	 * Get the header direction
	 *
	 * @since 1.0.0
	 */
	function cd_header_direction() {
		return ( get_theme_mod( 'header_direction', 'column' ) );
	}
	/**
	 * Get the header's sticky setting
	 *
	 * @since 1.0.0
	 */
	function cd_header_sticky() {
		return ( get_theme_mod( 'header_sticky', true ) );
	}
	/**
	 * Get whether using placefolder image or not.
	 *
	 * @since 1.1.2
	 */
	function cd_index_placefolder_image() {
		return ( get_theme_mod( 'index_placefolder_image', true ) );
	}
	/**
	 * Get whether displaying the date on index pages.
	 *
	 * @since 1.0.0
	 */
	function cd_index_meta_date() {
		return ( get_theme_mod( 'index_meta_date', true ) );
	}
	/**
	 * Get whether displaying the categories on index pages.
	 *
	 * @since 1.0.0
	 */
	function cd_index_meta_cat() {
		return ( get_theme_mod( 'index_meta_cat', true ) );
	}
	/**
	 * Get whether displaying the comments count on index pages.
	 *
	 * @since 1.0.0
	 */
	function cd_index_meta_comment() {
		return ( get_theme_mod( 'index_meta_comment', true ) );
	}
	/**
	 * Get the length of the excerpt.
	 *
	 * @since 1.0.0
	 */
	function cd_czr_excerpt_length() {
		return ( get_theme_mod( 'excerpt_length', 60 ) );
	}
	/**
	 * Get the ending strings of the excerpt.
	 *
	 * @since 1.0.0
	 */
	function cd_czr_excerpt_ending() {
		return ( get_theme_mod( 'excerpt_ending', '&#46;&#46;&#46;' ) );
	}
	/**
	 * Get whether displaying the date on single pages.
	 *
	 * @since 1.0.0
	 */
	function cd_is_meta_date() {
		return ( get_theme_mod( 'single_meta_date', true ) );
	}
	/**
	 * Get whether displaying the modified date on single pages.
	 *
	 * @since 1.0.0
	 */
	function cd_is_meta_modified() {
		return ( get_theme_mod( 'single_meta_modified_date', true ) );
	}
	/**
	 * Get whether displaying the categories on single pages.
	 *
	 * @since 1.0.0
	 */
	function cd_is_meta_cat() {
		return ( get_theme_mod( 'single_meta_cat', false ) );
	}
	/**
	 * Get whether displaying the author on single pages.
	 *
	 * @since 1.0.0
	 */
	function cd_is_meta_author() {
		return ( get_theme_mod( 'single_meta_author', true ) );
	}
	/**
	 * Get whether displaying the comments count on single pages.
	 *
	 * @since 1.0.0
	 */
	function cd_is_meta_com() {
		return ( get_theme_mod( 'single_meta_com', true ) );
	}
	/**
	 * Get whether displaying the tags on bottom of single pages.
	 *
	 * @since 1.0.0
	 */
	function cd_is_meta_btm_tag() {
		return ( get_theme_mod( 'single_meta_btm_tag', true ) );
	}
	/**
	 * Get whether displaying the categories on bottom of single pages.
	 *
	 * @since 1.0.0
	 */
	function cd_is_meta_btm_cat() {
		return ( get_theme_mod( 'single_meta_btm_cat', true ) );
	}
	/**
	 * Get whether displaying the author box on single pages.
	 *
	 * @since 1.0.0
	 */
	function cd_is_author_box() {
		return ( get_theme_mod( 'single_author_box', true ) );
	}
	/**
	 * Get whether displaying the post navigation on single pages.
	 *
	 * @since 1.0.0
	 */
	function cd_is_post_nav() {
		return ( get_theme_mod( 'single_post_nav', true ) );
	}
	/**
	 * Get whether displaying the related posts on single pages.
	 *
	 * @since 1.0.0
	 */
	function cd_is_post_related() {
		return ( get_theme_mod( 'single_related_posts', true ) );
	}
	/**
	 * Get whether displaying the comments on single pages.
	 *
	 * @since 1.0.0
	 */
	function cd_is_post_single_comment() {
		return ( get_theme_mod( 'single_comment', true ) );
	}
	/**
	 * Get the max articles shown on related posts.
	 *
	 * @since 1.0.0
	 */
	function cd_single_related_max() {
		return ( get_theme_mod( 'single_related_max', 6 ) );
	}
	/**
	 * Get the column number of related posts.
	 *
	 * @since 1.0.0
	 */
	function cd_single_related_col() {
		return ( get_theme_mod( 'single_related_col', 2 ) );
	}
	/**
	 * Get whether displaying the data on static pages.
	 *
	 * @since 1.1.1
	 */
	function cd_pages_meta_date() {
		return  ( get_theme_mod( 'pages_meta_date', false ) );
	}
	/**
	 * Get whether displaying the author on static pages.
	 *
	 * @since 1.1.1
	 */
	function cd_pages_meta_author() {
		return  ( get_theme_mod( 'pages_meta_author', false ) );
	}
	/**
	 * Get whether displaying the comments count on static pages.
	 *
	 * @since 1.1.1
	 */
	function cd_pages_meta_comments_count() {
		return  ( get_theme_mod( 'pages_meta_comments_count', false ) );
	}
	/**
	 * Get whether displaying theme credit or not.
	 *
	 * @since 1.0.0
	 */
	function cd_is_theme_credit() {
		return ( get_theme_mod( 'theme_credit', true ) );
	}
	/**
	 * Get the contents of the theme credit text.
	 *
	 * @since 1.0.0
	 */
	function cd_theme_credit_text() {
		return get_theme_mod( 'theme_credit_text', __( 'Coldbox WordPress theme by', 'coldbox' ) . ' <a href="' . esc_url( __( 'https://miruc.co/', 'coldbox' ) ) . '">' . __( 'Mirucon', 'coldbox' ) . '</a>' );
	}
	/**
	 * Get the contents of the credit text.
	 *
	 * @since 1.0.0
	 */
	function cd_credit() {
		$text = get_theme_mod( 'credit_text', '&copy;[year] <a href="[url]">[name]</a>' );
		$text = str_replace( '[year]', esc_html( date( 'Y' ) ), $text );
		$text = str_replace( '[url]', esc_url( home_url() ), $text );
		$text = str_replace( '[name]', esc_html( get_bloginfo( 'name' ) ), $text );
		return $text;
	}
	/**
	 * Get whether using of the hljs or not.
	 *
	 * @since 1.0.0
	 */
	function cd_use_normal_hljs() {
		return ( get_theme_mod( 'does_use_hljs', false ) );
	}
	/**
	 * Get whether using of the hljs with web package or not.
	 *
	 * @since 1.0.0
	 */
	function cd_use_web_hljs() {
		return ( get_theme_mod( 'use_hljs_web_pack', false ) );
	}
} // End if().

add_action( 'customize_register', 'cd_customize_register' );

// Load Social Links Setting.
get_template_part( 'czr/social-links' );

// Load Font Setting.
get_template_part( 'czr/customizer-font' );

// Load the inline styles got from the theme customizer.
get_template_part( 'czr/customizer-style' );
